@@ -8,11 +8,18 @@ from ..ext_exception import ExtException
 class MetaDataObject(MetaObject):
     versions = None
     version = None
+    _obj_name = None
 
     def __init__(self):
-        super(MetaDataObject, self).__init__()
+        super().__init__()
         self.path = ''
-        self.obj_name = None
+        self.new_dest_path = None
+        self.new_dest_dir = None
+        self.new_dest_file_name = None
+
+    @classmethod
+    def get_obj_name(cls):
+        return cls._obj_name if cls._obj_name else cls.__name__
 
     @classmethod
     def get_version(cls, version):
@@ -30,35 +37,64 @@ class MetaDataObject(MetaObject):
             self = cls()
             self.version = version
             self.decode_object(src_dir, file_name, dest_dir, dest_path, version, header_data)
-            tasks = self.decode_includes(src_dir, dest_dir, dest_path, header_data)
-            self.write_decode_object(dest_dir, dest_path, version)
+            self.set_write_decode_mode(dest_dir, dest_path)
+            tasks = self.decode_includes(src_dir, dest_dir, self.new_dest_path, header_data)
+            self.write_decode_object(dest_dir, self.new_dest_path, self.new_dest_file_name, version)
             return tasks
+        except ExtException as err:
+            raise ExtException(
+                parent=err,
+                message=err.message + err.detail,
+                detail=f'in decode {cls.__name__}',
+                action=f'{cls.__name__}.decode'
+            ) from err
         except Exception as err:
             raise ExtException(
                 parent=err,
-                message=str(err),
                 action=f'{cls.__name__}.decode'
             ) from err
 
+    def set_write_decode_mode(self, dest_dir, dest_path):
+        self.set_mode_decode_in_root_folder(dest_dir, dest_path)
+
     def decode_object(self, src_dir, file_name, dest_dir, dest_path, version, header_data):
         self.set_header_data(header_data)
 
-    def write_decode_object(self, dest_dir, dest_path, version):
-        helper.json_write(self.header, os.path.join(dest_dir, dest_path), f'{self.header["name"]}.json')
-        self.write_decode_code(os.path.join(dest_dir, dest_path), self.header["name"])
+    def write_decode_object(self, dest_dir, dest_path, file_name, version):
+        dest_full_path = os.path.join(dest_dir, dest_path)
+        helper.json_write(self.header, dest_full_path, f'{file_name}.json')
+        self.write_decode_code(dest_full_path, file_name)
+
+    def set_mode_decode_in_name_folder(self, dest_dir, dest_path):
+        self.new_dest_path = os.path.join(dest_path, self.header['name'])
+        self.new_dest_dir = os.path.join(dest_dir, self.new_dest_path)
+        self.new_dest_file_name = self.get_obj_name()
+        os.makedirs(self.new_dest_dir)
+
+    def set_mode_decode_in_root_folder(self, dest_dir, dest_path):
+        self.new_dest_path = dest_path
+        self.new_dest_dir = os.path.join(dest_dir, self.new_dest_path)
+        self.new_dest_file_name = self.header['name']
 
     @classmethod
     def encode(cls, src_dir, file_name, dest_dir, version):
         self = cls()
         self.version = version
+        file_name = self.get_encode_file_name(file_name)
         try:
             self.header = helper.json_read(src_dir, f'{file_name}.json')
             self.encode_object(src_dir, file_name, dest_dir, version)
             self.write_encode_object(dest_dir)
             return self.encode_includes(src_dir, dest_dir)
         except Exception as err:
-            msg = f'{cls.__name__}: {err}'
-            raise Exception(msg) from err
+            raise ExtException(
+                parent=err,
+                dump=dict(src_dir=src_dir, file_name=file_name),
+                action=f'{cls.__name__}.encode') from err
+
+    @classmethod
+    def get_encode_file_name(cls, file_name):
+        return file_name
 
     def encode_object(self, src_dir, file_name, dest_dir, version):
         msg = f'Нет реализации для "{self.__class__.__name__}"'
